Probabilistic Models
==================================

This module provides probabilistic model implementations for concept-based reasoning.

.. currentmodule:: torch_concepts.nn

Summary
-------

**Model Classes**

.. autosummary::
   :toctree: generated
   :nosignatures:

   ProbabilisticModel
   ParametricCPD
   BipartiteModel
   GraphModel


Class Documentation
-------------------

.. autoclass:: ProbabilisticModel
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: ParametricCPD
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: BipartiteModel
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: GraphModel
   :members:
   :undoc-members:
   :show-inheritance:
